==> jc-1.4.0.tar.gz: java/lang/String__24CaseInsensitiveComparator.h <==
// final class java.lang.String$CaseInsensitiveComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6988263cdb8e7b91 java_lang_String__24CaseInsensitiveComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_String__24CaseInsensitiveComparator_H_
#define _JC_java_lang_String__24CaseInsensitiveComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs	_jc_java_lang_String__24CaseInsensitiveComparator$sub_refs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs	_jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$refs	_jc_java_lang_String__24CaseInsensitiveComparator$refs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$nonrefs	_jc_java_lang_String__24CaseInsensitiveComparator$nonrefs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$object	_jc_java_lang_String__24CaseInsensitiveComparator$object;

typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct	_jc_java_lang_String__24CaseInsensitiveComparator$fields_struct;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vmethods	_jc_java_lang_String__24CaseInsensitiveComparator$vmethods;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vtable	_jc_java_lang_String__24CaseInsensitiveComparator$vtable;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vtype	_jc_java_lang_String__24CaseInsensitiveComparator$vtype;

// Class fields structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct _jc_java_lang_String__24CaseInsensitiveComparator$class_fields;

// Constructors
extern void _jc_java_lang_String__24CaseInsensitiveComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *);

// Virtual methods
extern jint _jc_java_lang_String__24CaseInsensitiveComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_String__24CaseInsensitiveComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_lang_String__24CaseInsensitiveComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_String__24CaseInsensitiveComparator$vmethods	java_lang_String__24CaseInsensitiveComparator;
};

// Vtype
struct _jc_java_lang_String__24CaseInsensitiveComparator$vtype {
	_jc_type			type;
	_jc_java_lang_String__24CaseInsensitiveComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_String__24CaseInsensitiveComparator$refs {
    _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs	java_lang_String__24CaseInsensitiveComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_String__24CaseInsensitiveComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs	java_lang_String__24CaseInsensitiveComparator;
};

// Object instance structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$object {
	_jc_java_lang_String__24CaseInsensitiveComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_String__24CaseInsensitiveComparator$vtype	*vtype;
	_jc_java_lang_String__24CaseInsensitiveComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_String__24CaseInsensitiveComparator$vtype _jc_java_lang_String__24CaseInsensitiveComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_String__24CaseInsensitiveComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_String__24CaseInsensitiveComparator$class_object;

#endif	/* _JC_java_lang_String__24CaseInsensitiveComparator_H_ */

==> jc-1.4.5.tar.gz: java/lang/String__24CaseInsensitiveComparator.h <==
// final class java.lang.String$CaseInsensitiveComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 342d6eaff6cc1f3f java_lang_String__24CaseInsensitiveComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_String__24CaseInsensitiveComparator_H_
#define _JC_java_lang_String__24CaseInsensitiveComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs	_jc_java_lang_String__24CaseInsensitiveComparator$sub_refs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs	_jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$refs	_jc_java_lang_String__24CaseInsensitiveComparator$refs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$nonrefs	_jc_java_lang_String__24CaseInsensitiveComparator$nonrefs;
typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$object	_jc_java_lang_String__24CaseInsensitiveComparator$object;

typedef struct _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct	_jc_java_lang_String__24CaseInsensitiveComparator$fields_struct;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vmethods	_jc_java_lang_String__24CaseInsensitiveComparator$vmethods;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vtable	_jc_java_lang_String__24CaseInsensitiveComparator$vtable;
typedef const struct _jc_java_lang_String__24CaseInsensitiveComparator$vtype	_jc_java_lang_String__24CaseInsensitiveComparator$vtype;

// Class fields structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_String__24CaseInsensitiveComparator$fields_struct _jc_java_lang_String__24CaseInsensitiveComparator$class_fields;

// Constructors
extern void _jc_java_lang_String__24CaseInsensitiveComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_lang_String__24CaseInsensitiveComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_String__24CaseInsensitiveComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_lang_String__24CaseInsensitiveComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_String__24CaseInsensitiveComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_String__24CaseInsensitiveComparator$vmethods	java_lang_String__24CaseInsensitiveComparator;
};

// Vtype
struct _jc_java_lang_String__24CaseInsensitiveComparator$vtype {
	_jc_type			type;
	_jc_java_lang_String__24CaseInsensitiveComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_String__24CaseInsensitiveComparator$refs {
    _jc_java_lang_String__24CaseInsensitiveComparator$sub_refs	java_lang_String__24CaseInsensitiveComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_String__24CaseInsensitiveComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_String__24CaseInsensitiveComparator$sub_nonrefs	java_lang_String__24CaseInsensitiveComparator;
};

// Object instance structure
struct _jc_java_lang_String__24CaseInsensitiveComparator$object {
	_jc_java_lang_String__24CaseInsensitiveComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_String__24CaseInsensitiveComparator$vtype	*vtype;
	_jc_java_lang_String__24CaseInsensitiveComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_String__24CaseInsensitiveComparator$vtype _jc_java_lang_String__24CaseInsensitiveComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_String__24CaseInsensitiveComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_String__24CaseInsensitiveComparator$class_object;

#endif	/* _JC_java_lang_String__24CaseInsensitiveComparator_H_ */
